@@ -177,6 +177,13 @@ typedef enum
   G_DESKTOP_TOUCHPAD_CLICK_METHOD_FINGERS
 } GDesktopTouchpadClickMethod;
 
+typedef enum
+{
+  G_DESKTOP_TOUCHPAD_BUTTON_TAP_MAP_DEFAULT,
+  G_DESKTOP_TOUCHPAD_BUTTON_TAP_MAP_LRM,
+  G_DESKTOP_TOUCHPAD_BUTTON_TAP_MAP_LMR
+} GDesktopTouchpadTapButtonMap;
+
 typedef enum
 {
   G_DESKTOP_DEVICE_SEND_EVENTS_ENABLED,
@@ -220,4 +227,35 @@ typedef enum
   G_DESKTOP_USB_PROTECTION_ALWAYS
 } GDesktopUsbProtection;
 
+typedef enum
+{
+  G_DESKTOP_FONT_ANTIALIASING_MODE_NONE,
+  G_DESKTOP_FONT_ANTIALIASING_MODE_GRAYSCALE,
+  G_DESKTOP_FONT_ANTIALIASING_MODE_RGBA,
+} GDesktopFontAntialiasingMode;
+
+typedef enum
+{
+  G_DESKTOP_FONT_HINTING_NONE,
+  G_DESKTOP_FONT_HINTING_SLIGHT,
+  G_DESKTOP_FONT_HINTING_MEDIUM,
+  G_DESKTOP_FONT_HINTING_FULL,
+} GDesktopFontHinting;
+
+typedef enum
+{
+  G_DESKTOP_FONT_RGBA_ORDER_RGBA,
+  G_DESKTOP_FONT_RGBA_ORDER_RGB,
+  G_DESKTOP_FONT_RGBA_ORDER_BGR,
+  G_DESKTOP_FONT_RGBA_ORDER_VRGB,
+  G_DESKTOP_FONT_RGBA_ORDER_VBGR,
+} GDesktopFontRgbaOrder;
+
+typedef enum
+{
+  G_DESKTOP_COLOR_SCHEME_DEFAULT,
+  G_DESKTOP_COLOR_SCHEME_PREFER_DARK,
+  G_DESKTOP_COLOR_SCHEME_PREFER_LIGHT,
+} GDesktopColorScheme;
+
 #endif /* __gdesktop_enums_h__ */
